init

Function init 

pub fn init(
    peripheral: &mut Peripheral,
    lib: TSLibrary,
    txs: Arc<RwLock<Transmitters>>,
) -> Result<(), PluginError>
Initializes a new plugin.

Arguments

  • peripheral - A Peripheral model instance that will be updated with the Plugin’s information
  • lib - A copy of the Library that contains the implementation of the peripheral’s Plugin API
  • txs - The set of transmitters currently known to the daemon