pub fn init(
peripheral: &mut Peripheral,
lib: TSLibrary,
txs: Arc<RwLock<Transmitters>>,
) -> Result<(), PluginError>Expand description
Initializes a new plugin.
Arguments
peripheral- A Peripheral model instance that will be updated with the Plugin’s informationlib- A copy of the Library that contains the implementation of the peripheral’s Plugin APItxs- The set of transmitters currently known to the daemon